Option Explicit

'Private Declare Sub Sleep Lib "kernel32" (ByVal dwMilliseconds)
'LabSat 3 API VBScript sample.
'To execute pass in the the command line arguments in the form of <Serial Number or IP Address> and <Playback filename>

'External Ref constants
Const ExternalReferenceCom_NotSet = -1
Const ExternalReferenceCom_OCXO = 2
Const ExternalReferenceCom_YES = 1
Const ExternalReferenceCom_TCXO = 2

Const YesNoNotSet_No = 0
Const YesNoNotSet_NotSet = -1
Const YesNoNotSet_Yes = 1

'Channel Constants
Const Channel1 = "CHANNEL1"
Const Channel2 = "CHANNEL2"
Const Channel3 = "CHANNEL3"
Const Channel4 = "CHANNEL4"

'Record mode constants
Const ChannelDigitalRecordModeCom_NotSet = -1
Const ChannelDigitalRecordModeCom_OFF = 0
Const ChannelDigitalRecordModeCom_1PPS = 1
Const ChannelDigitalRecordModeCom_CAN1 = 2
Const ChannelDigitalRecordModeCom_CAN2 = 3
Const ChannelDigitalRecordModeCom_RS232 = 4
Const ChannelDigitalRecordModeCom_DIG1 = 5
Const ChannelDigitalRecordModeCom_DIG2 = 6

Const BandwidthNotSet = -1
Const Bandwidth10 = 10
Const Bandwidth30 = 30
Const Bandwidth56 = 56

Const QuantisationNotSet = -1
Const Quantisation1 = 1
Const Quantisation2 = 2
Const Quantisation3 = 3

Dim labsat 'As New LabSat3WBAPI.LabSatApiCom
Dim FileName
Dim LabSatIPAddress

Private Sub StartProcess()

    Call WScript.Echo("Start")
    Set labsat = WScript.CreateObject("Racelogic.LabSat3WBAPI.LabSatApiCom")
    
    FileName = "MyTestScenario"
    LabSatIPAddress = "192.168.1.112"

    labsat.Config.ConfigPlay.Options.Loop = 1
    With labsat
        .Version = 3
        'Get the serial number from the first command line argument
        .SerialNumberOrIpAddress = "192.168.1.112"
    End With

    
    Call WScript.Echo("Configure LabSat")
    
    Call WScript.Echo("Configure Display")
    
' '    'Reset to default
    Call ConfigDisplay(50, 50)

    WScript.Sleep(1000)
' '    'Configure Display
    Call ConfigDisplay(20, 100)
    
    WScript.Sleep(1000)

    Call WScript.Echo("Configure Time")
   'Configure the time of the device
    Call ManuallyConfigTime

    Call ConfigUTCTime

    'Configure Constellations   
    Call WScript.Echo("Configure Constellation")
   'Configure the device to use UTC time
    Call ConfigConstellation(Bandwidth30, Quantisation2, 1585,1233,0)
    
    Call WScript.Echo("Configure Digital record mode")
     'Set Channel 1 Digital Record mode to Digital
     Call ConfigDigitalRecordMode(Channel1, ChannelDigitalRecordModeCom_DIG1)


    'Switch Channel 2 Digital Record mode to digital 2
    Call ConfigDigitalRecordMode(Channel2, ChannelDigitalRecordModeCom_DIG2)

    Call WScript.Echo("Record File " & FileName)
        
    Call RecordFile(FileName, 0)
    
    'wait for 10 seconds
    WScript.Sleep 10000
    
    Call WScript.Echo("Stop Recording")
    Call StopRecording

    'Playback file specified in the 2nd argument of the script from the beginning to the end    
    Call WScript.Echo("Play File " & FileName)
    
    Call Play(FileName, 0, 0)
    
    'Sleep for 10 seconds
    WScript.Sleep 10000
    
    'Stop the playback
    Call StopPlayback
End Sub


'Finds the specified LabSat 3 device
Sub Find()
    labsat.Find.Command.Run
End Sub

'Configures the brightness and contrast of the display
Sub ConfigDisplay(brightness, contrast)
    With labsat
        If Not IsNull(brightness) Then
            .Config.ConfigSetupDisplay.Options.brightness = brightness
            .Config.ConfigSetupDisplay.Options.SetBrightness = True
        End If
    
        If Not IsNull(contrast) Then
            .Config.ConfigSetupDisplay.Options.contrast = contrast
            .Config.ConfigSetupDisplay.Options.SetContrast = True
        End If
                    
        .Config.ConfigSetupDisplay.Command.Run
    End With
End Sub

'Manually configures the device time to the current date time
Sub ManuallyConfigTime()
    With labsat
        .Config.ConfigSetup.Options.SetDeviceTime = Now
        .Config.ConfigSetup.Options.UseUtcTime = YesNoNotSet_No
        
        .Config.ConfigSetup.Command.Run
    End With
End Sub

'Configures the device to use UTC time
Sub ConfigUTCTime()
    With labsat
        'Set the date to the minimum date in VBScript, so that the API ignores the date time if previously set by this API session
        .Config.ConfigSetup.Options.SetDeviceTime = DateSerial(100, 1, 1)
        .Config.ConfigSetup.Options.UseUtcTime = YesNoNotSet_Yes
        
        .Config.ConfigSetup.Command.Run
    End With
End Sub

'Configures the constellations enabled/disabled status.
Sub ConfigConstellation(bandwidth, quantisation, frequency1,frequency2,frequency3)
    
    'wait for 1 second before configuring constellation
    WScript.Sleep 1000

    'For each parameter true, false or nothing values can be specified
    With labsat
        .Config.ConfigConstellation.Options.bandwidth = bandwidth
        .Config.ConfigConstellation.Options.Quantization = quantisation
        .Config.ConfigConstellation.Options.frequency1 = frequency1
        .Config.ConfigConstellation.Options.frequency2 = frequency2
        .Config.ConfigConstellation.Options.frequency3 = frequency3
        
        .Config.ConfigConstellation.Command.Run
    End With
    
End Sub

'Sets a constellation to two bit
Sub ConfigConstellationTwoBit(constellation, twoBitEnabled)
'Use the constellation constants (GPS, Beidou, Glonass) to pass in the required constellation to set to two bit
    With labsat
        Select Case constellation
            Case Gps
                .Config.ConfigConstellation.Options.IsGpsEnabled = YesNoNotSet_Yes
            Case Glonass
                .Config.ConfigConstellation.Options.IsGlonassEnabled = YesNoNotSet_Yes
            Case Beidou
                .Config.ConfigConstellation.Options.IsBeidouEnabled = YesNoNotSet_Yes
            Case Else
                Exit Sub
        End Select
        
        .Config.ConfigConstellation.Options.IsTwoBitEnabled = twoBitEnabled
        
        .Config.ConfigConstellation.Command.Run
    End With
End Sub

'Set the channel digital record mode
Sub ConfigDigitalRecordMode(channel, channelDigitalRecordMode)
    With labsat
        If channel = Channel1 Then
            .Config.ConfigSetup.Options.Channel1DigitalRecordMode = channelDigitalRecordMode
        ElseIf channel = Channel2 Then
            .Config.ConfigSetup.Options.Channel2DigitalRecordMode = channelDigitalRecordMode
        ElseIf channel = Channel3 Then
            .Config.ConfigSetup.Options.Channel3DigitalRecordMode = channelDigitalRecordMode
        End If
        
        .Config.ConfigSetup.Command.Run
    End With
End Sub

'Enables or disables the live NMEA stream (Use during playback)
Sub ConfigNMEAStream(enabled)
    With labsat
        .Monitor.Options.NmeaEnabled = enabled
        .Monitor.Command.Run
    End With
End Sub

'Applies attenuation level to all constellations (Use during playback)
Sub SetAttenuationLevel(level)
    With labsat
        .Attenuation.Options.AttenuationLevel = level
        .Attenuation.Command.Run
    End With
End Sub

'Sets attenuation level on specified constellations (Use during playback)
Sub SetAttenuationLevelOnConstellation(level, applyToGps, applyToGlonass, applyToBeidou)
    With labsat
        .Attenuation.Options.AttenuationLevel = level
        .Attenuation.Options.applyToGps = applyToGps
        .Attenuation.Options.applyToGlonass = applyToGlonass
        .Attenuation.Options.applyToBeidou = applyToBeidou
        
        .Attenuation.Options.Run
    End With
End Sub

'Applies noise level to all constellations (Use during playback)
Sub SetNoiseLevel(level)
    With labsat
        .Noise.Options.NoiseLevel = level
        .Noise.Command.Run
    End With
End Sub

'Sets noise level on specified constellations (Use during playback)
Sub SetNoiseLevelOnConstellation(level, applyToGps, applyToGlonass, applyToBeidou)
    With labsat
        .Noise.Options.NoiseLevel = level
        .Noise.Options.applyToGps = applyToGps
        .Noise.Options.applyToGlonass = applyToGlonass
        .Noise.Options.applyToBeidou = applyToBeidou
        
        .Noise.Command.Run
    End With
End Sub

'Mutes or Unmutes all satelite constellations (Use during playback)
Sub Mute(muted)
    With labsat
        .Mute.Options.IsMute = muted
        .Mute.Command.Run
    End With
End Sub

'Mutes or Unmutes specified satelite constellations (Use during playback)
Sub MuteConstellation(muted, applyToGps, applyToGlonass, applyToBeidou)
    With labsat
        .Mute.Options.IsMute = muted
        .Mute.Options.applyToGps = applyToGps
        .Mute.Options.applyToGlonass = applyToGlonass
        .Mute.Options.applyToBeidou = applyToBeidou
        
        .Mute.Command.Run
    End With
End Sub

'Plays back the specified playback file
Sub Play(fileName, fromSeconds, playForSeconds)
    With labsat
        'fileName - the scenario file to playback
        .PlayFile.Options.fileName = fileName
        
        'fromSeconds - the position in the playback file to start from
        If fromSeconds <> 0 Then
            .PlayFile.Options.fromSeconds = fromSeconds
        End If
        
        'playForSeconds - how long to play the file for
        If playForSeconds <> 0 Then
            .PlayFile.Options.playForSeconds = playForSeconds
        End If
        
        .PlayFile.Command.Run
    End With
End Sub

'Stops playback of the scenario playback file
Sub StopPlayback()
    With labsat
        .PlayFile.Options.Stop = YesNoNotSet_Yes
        .PlayFile.Command.Run
    End With
End Sub

'Record with a default filename
Sub Record()
    With labsat
        .RecordFile.Command.Run
    End With
End Sub

'Record with a specified filename and a set duration (in seconds)
Sub RecordFile(fileName, duration)
    With labsat
        .RecordFile.Options.fileName = fileName
        
        'only set record duration if the duration isn't 0
        If duration <> 0 Then
            .RecordFile.Options.RecordForSeconds = duration
        End If
        
        .RecordFile.Command.Run
    End With
End Sub

'Stops the recording
Sub StopRecording()
    With labsat
        .RecordFile.Options.Stop = YesNoNotSet_Yes
        .RecordFile.Command.Run
    End With
End Sub

'call main method
StartProcess